@@ -1,12 +1,3 @@
-# $Id: GetInfoReturn.pm 8696 2007-01-24 23:12:38Z Tim $
-#
-# Copyright (c) 2002  Tim Bunce  Ireland
-#
-# Constant data describing return values from the DBI getinfo function.
-#
-# You may distribute under the terms of either the GNU General Public
-# License or the Artistic License, as specified in the Perl README file.
-
 package DBI::Const::GetInfoReturn;
 
 use strict;
@@ -18,21 +9,14 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %GetInfoReturnTypes %GetInfoReturnValues);
 @ISA = qw(Exporter);
 @EXPORT = qw(%GetInfoReturnTypes %GetInfoReturnValues);
 
-my
-$VERSION = "2.008697";
-
 =head1 NAME
-
+ 
 DBI::Const::GetInfoReturn - Data and functions for describing GetInfo results
-
+ 
 =head1 SYNOPSIS
 
 The interface to this module is undocumented and liable to change.
 
-=head1 DESCRIPTION
-
-Data and functions for describing GetInfo results
-
 =cut
 
 use DBI::Const::GetInfoType;
